#!/bin/sh

SHELL_VARS_SET=1

RRR_WITH_SYSTEMD=yes
RRR_WITH_PYTHON3=yes
RRR_WITH_PERL5=yes
RRR_WITH_MYSQL=yes
RRR_WITH_OPENSSL=yes
RRR_WITH_OPENSSL_CRYPT=
RRR_WITH_LIBRESSL=no
RRR_WITH_AUTO_SSL=yes
